Installing Rucio daemons
========================

Prerequisites
~~~~~~~~~~~~~

Rucio server runs on Python 2.6, 2.7.

Platforms: Rucio should run on any Unix-like platform.

Python Dependencies
~~~~~~~~~~~~~~~~~~~

Rucio server needs the following python modules:

.. literalinclude:: ../../tools/pip-requires
   :lines: 2-8

All Dependencies are automatically installed with pip.

Install via docker
~~~~~~~~~~~~~~~~~~

